==> apache-arrow-16.1.0_2.arm64_ventura.bottle.tar.gz: apache-arrow/16.1.0_2/lib/cmake/ArrowDataset/ArrowDatasetTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ArrowDataset::arrow_dataset_shared" for configuration "RELEASE"
set_property(TARGET ArrowDataset::arrow_dataset_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowDataset::arrow_dataset_shared PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_dataset.1601.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/16.1.0_2/lib/libarrow_dataset.1601.dylib"
  )

list(APPEND _cmake_import_check_targets ArrowDataset::arrow_dataset_shared )
list(APPEND _cmake_import_check_files_for_ArrowDataset::arrow_dataset_shared "${_IMPORT_PREFIX}/lib/libarrow_dataset.1601.0.0.dylib" )

# Import target "ArrowDataset::arrow_dataset_static" for configuration "RELEASE"
set_property(TARGET ArrowDataset::arrow_dataset_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowDataset::arrow_dataset_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_dataset.a"
  )

list(APPEND _cmake_import_check_targets ArrowDataset::arrow_dataset_static )
list(APPEND _cmake_import_check_files_for_ArrowDataset::arrow_dataset_static "${_IMPORT_PREFIX}/lib/libarrow_dataset.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> apache-arrow-18.0.0.arm64_ventura.bottle.tar.gz: apache-arrow/18.0.0/lib/cmake/ArrowDataset/ArrowDatasetTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ArrowDataset::arrow_dataset_shared" for configuration "RELEASE"
set_property(TARGET ArrowDataset::arrow_dataset_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowDataset::arrow_dataset_shared PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_dataset.1800.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/18.0.0/lib/libarrow_dataset.1800.dylib"
  )

list(APPEND _cmake_import_check_targets ArrowDataset::arrow_dataset_shared )
list(APPEND _cmake_import_check_files_for_ArrowDataset::arrow_dataset_shared "${_IMPORT_PREFIX}/lib/libarrow_dataset.1800.0.0.dylib" )

# Import target "ArrowDataset::arrow_dataset_static" for configuration "RELEASE"
set_property(TARGET ArrowDataset::arrow_dataset_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowDataset::arrow_dataset_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_dataset.a"
  )

list(APPEND _cmake_import_check_targets ArrowDataset::arrow_dataset_static )
list(APPEND _cmake_import_check_files_for_ArrowDataset::arrow_dataset_static "${_IMPORT_PREFIX}/lib/libarrow_dataset.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
